import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useEffect } from 'react';
import { useTranslation } from 'react-i18next';
import { NavLink, useLocation, useNavigate } from 'react-router-dom';
import './SiteNav.css';
import { getLang } from './getLang.js';
import { getRoutePath } from './getRoutePath.js';
import { setLang } from './setLang.js';
export function SiteNav({ docs, languages }) {
    const location = useLocation();
    const navigate = useNavigate();
    const { i18n } = useTranslation();
    useEffect(() => {
        const newPath = setLang(location.pathname, i18n.language);
        if (newPath !== location.pathname) {
            navigate(newPath);
        }
    }, [i18n.language, location.pathname, navigate]);
    const docsFilteredByLang = docs
        .filter((doc) => getLang(doc.filepath) === i18n.language)
        .map((doc) => ({
        title: doc.title,
        path: getRoutePath(doc.filepath),
        group: doc.frontmatter?.group,
        order: doc.frontmatter?.order,
    }))
        .sort((a, b) => {
        if (typeof a.order === 'number' && typeof b.order === 'number') {
            return a.order - b.order;
        }
        else if (typeof a.order === 'number') {
            return -1;
        }
        else if (typeof b.order === 'number') {
            return 1;
        }
        else {
            return a.path.localeCompare(b.path);
        }
    });
    const groups = [];
    docsFilteredByLang.forEach((doc) => {
        if (doc.group && !groups.includes(doc.group)) {
            groups.push(doc.group);
        }
    });
    return (_jsx("aside", { className: "doc-ui-site-nav", children: _jsxs("nav", { className: "doc-ui-site-nav-inner", children: [_jsx("div", { className: "doc-ui-site-settings", children: languages && (_jsx("select", { value: i18n.language, onChange: (e) => i18n.changeLanguage(e.target.value), children: languages.map((lang) => (_jsx("option", { value: lang.code, children: lang.name }, lang.code))) })) }), docsFilteredByLang
                    .filter((doc) => !doc.group)
                    .map((doc) => (_jsx(NavLink, { className: "doc-ui-site-nav-item", to: getRoutePath(doc.path), end: true, children: doc.title }, doc.path))), groups.map((group) => (_jsxs("div", { className: "doc-ui-site-nav-group", children: [_jsx("div", { className: "doc-ui-site-nav-group-title", children: group }), docsFilteredByLang
                            .filter((doc) => group === doc.group)
                            .map((doc) => (_jsx(NavLink, { className: "doc-ui-site-nav-item", to: getRoutePath(doc.path), end: true, children: doc.title }, doc.path)))] }, group)))] }) }));
}
